package com.djhk.uav.versioninfo.mapper;

import com.djhk.uav.versioninfo.domain.VersionInfo;

import java.util.List;

/**
 * 版本公告Mapper接口
 * 
 * @author qpc
 * @date 2025-04-10
 */
public interface VersionInfoMapper 
{
    /**
     * 查询版本公告
     * 
     * @param id 版本公告主键
     * @return 版本公告
     */
    public VersionInfo selectVersionInfoById(Long id);

    /**
     * 查询版本公告列表
     * 
     * @param versionInfo 版本公告
     * @return 版本公告集合
     */
    public List<VersionInfo> selectVersionInfoList(VersionInfo versionInfo);

    /**
     * 新增版本公告
     * 
     * @param versionInfo 版本公告
     * @return 结果
     */
    public int insertVersionInfo(VersionInfo versionInfo);

    /**
     * 修改版本公告
     * 
     * @param versionInfo 版本公告
     * @return 结果
     */
    public int updateVersionInfo(VersionInfo versionInfo);

    /**
     * 删除版本公告
     * 
     * @param id 版本公告主键
     * @return 结果
     */
    public int deleteVersionInfoById(Long id);

    /**
     * 批量删除版本公告
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteVersionInfoByIds(Long[] ids);
}
